import React from 'react';
import { Link } from 'react-router-dom';
import styled from 'styled-components'
import Grid from '@material-ui/core/Grid';
import Card from '@material-ui/core/Card';
import Button from '@material-ui/core/Button';

export default function FormationMaterialHeader(props) {
	const colecao = props.colecao;
	const colecao_obj = props.colecao_obj;
	const topico_obj = props.topico_obj;

	const get_title = () => {
		return colecao ?
						colecao_obj.name
						: (topico_obj.pre_title + topico_obj.title);
	}

	const get_subtitle = () => {
		return colecao ?
					colecao_obj.topics.length+' '+colecao_obj.topic_name
					: colecao_obj.name;
	}

  return (
		<WrappingCard>
				<Grid container
					direction="row"
					justify="flex-start"
					alignItems="stretch"
				>
					<Grid item xs={5}>
						<Img src={require(`../../public/${colecao_obj.img}`)}/>
					</Grid>
					<Grid item container xs={7}
						direction="column"
						justify="flex-start"
						alignItems="stretch"
					>
						<Grid item>
							<Title>{get_title()}</Title>
						</Grid>
						<Grid item>
							<SubTitle>
								{ colecao ? 
										get_subtitle()
										: <StyledLink to={'/colecao?id='+colecao_obj.id}>{get_subtitle()}</StyledLink> }
							</SubTitle>
						</Grid>
						<Grid item>
							<TagList>
								{colecao_obj.tags.map((t) => {
									return (<Badge>{t.name}</Badge>);
								})}
							</TagList>
						</Grid>		
						<Grid item>
							{ colecao ? 	
									<Button
										variant="contained"
										color="secondary"
										style={{marginLeft: '15px'}}
										onClick={props.handleClick}
									>
										{ props.colecao ? "Ver todos os módulos" : "Iniciar leitura" }
									</Button>
									:
									<StyledLink to={'/iframe-colecao?colecao='+colecao_obj.id+'&topico='+topico_obj.id}>
										<Button
											variant="contained"
											color="secondary"
											style={{marginLeft: '15px'}}
											onClick={props.handleClick}
										>
											{ props.colecao ? "Ver todos os módulos" : "Iniciar leitura" }
										</Button>
									</StyledLink>
							}
						</Grid>
					</Grid>
				</Grid>
		</WrappingCard>
  );
}

const Badge=styled.span`
	background-color: #e5e5e5;
	color: #666;
	border-radius: 15px;
	margin-left: 5px;
	padding: 3px 7px;
	line-height: 1.2em;
	font-size: 0.7em;
	display: inline-block;
`
const TagList=styled.div`
	margin-bottom: 10px;
	width: 100%;
	margin-left: 10px;
`
const Img=styled.img`
	max-width: 100%;
	background-color: #e5e5e5;
	display: inline-block;
`
const Title=styled.h1`
	font-weight: 100;
	margin: 15px;
	color: rgb(102, 102, 102);
`
const SubTitle=styled.h3`
	font-weight: 100;
	margin: 15px;;
	margin-top: 0;
	color: rgb(102, 102, 102);
`
export const WrappingCard=styled(Card)`
		border-radius: 0;
		height: 250px !important;
		margin-right : auto;
		margin-left : auto;
		margin-bottom: 30px;
		margin-top: 30px;

		@media screen and (max-width: 768px) {
				width : 100% !important;
		}
		@media screen and (min-width: 992px) {
				width : 770px;
		}
		@media screen and (min-width: 1200px) {
				width : 970px !important;
		}
`
const StyledLink = styled(Link)`
	text-decoration: none !important;
	color: inherit !important;
`
